#!/bin/sh

USAGE="usage $0 <version>\npublish a version of go-ipfs to npm"
if [ "$#" -ne 1 ]; then
  echo $USAGE
  exit 0
fi
# arguments: <version>
version=$1

die() {
  echo >&2 "error: $@"
  exit 1
}

# check the version is indeed a tag in go-ipfs
repo="https://github.com/ipfs/go-ipfs"
git ls-remote -t $repo | egrep "refs/tags/v$version$" >/dev/null 2>&1 ||
  die "$version not a tag in $repo"

# ok, publishing now.

# update version in package.json
json -I -f package.json -e "this.version='$version'"

# publish to github + npm
git add package.json
git commit -m "v$version"
git push origin master
npm publish
